Finite Volume methods
=====================

The different models here demonstrate various uses of the finite volume
differencing operators. See [the finite volume documentation][fvdocs] for more
information.

[fvdocs]: https://bout-dev.readthedocs.io/en/latest/user_docs/differential_operators.html#finite-volume-conservative-finite-difference-methods
